@@ -112,7 +112,7 @@ static const TModel ModelList[]={
 	{ MFG_HAR,	"Harmony 650",			NULL },
 	{ MFG_HAR,	"Harmony 600i",			NULL },
 	{ MFG_HAR,	"Harmony 650i",			NULL },
-	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_HAR,	"Harmony 665",			NULL },
 	{ MFG_UNK,	"Unknown",			NULL },
 	{ MFG_UNK,	"Unknown",			NULL },
 	{ MFG_HAR,	"Harmony 300",			NULL },
@@ -149,6 +149,17 @@ static const TModel ModelList[]={
 	{ MFG_HAR,	"Harmony Home Hub",		NULL },
 	{ MFG_UNK,	"Unknown",			NULL },
 	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+// 110
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_HAR,	"Harmony 950",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
+	{ MFG_UNK,	"Unknown",			NULL },
 	{ MFG_UNK,	"Unknown",			NULL }
 };
 
